@@ -89,6 +89,8 @@ load_choices (Druid *data)
 		gnome_config_get_bool ("/firestarter/Druid/x"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->dhcp),
 		gnome_config_get_bool ("/firestarter/Druid/dhcp"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->upnp),
+		gnome_config_get_bool ("/firestarter/Druid/upnp"));
 
 	/* ICMP filtering */
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->icmp_echo),
@@ -200,6 +202,8 @@ save_choices (Druid *data)
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->x)));
 	gnome_config_set_bool ("/firestarter/Druid/dhcp",
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->dhcp)));
+	gnome_config_set_bool ("/firestarter/Druid/upnp",
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->upnp)));
 
 	/* ICMP filtering */
 	gnome_config_set_bool ("/firestarter/Druid/icmp_echo",
