@@ -622,6 +622,9 @@ create_services_page (Druid *data)
 	data->ipsec = gtk_check_button_new_with_label ("IPSEC");
 	gtk_box_pack_start (GTK_BOX (vbox), data->ipsec, FALSE, FALSE, 0);
 
+	data->upnp = gtk_check_button_new_with_label ("uPNP");
+	gtk_box_pack_start (GTK_BOX (vbox), data->upnp, FALSE, FALSE, 0);
+
 	gtk_box_pack_start (GTK_BOX (data->services), vbox, FALSE, FALSE, 0);
 
 	gtk_widget_show_all (table);
