@@ -29,7 +29,7 @@
 static void goto_homepage (void);
 
 static GnomeUIInfo docklet_menu [] = {
-	GNOMEUIINFO_ITEM (N_("R_estart firewall"), NULL, restart_firewall, start_xpm),
+	GNOMEUIINFO_ITEM (N_("Start _firewall"), NULL, restart_firewall, start_xpm),
 	GNOMEUIINFO_ITEM (N_("_Stop firewall"), NULL, stop_firewall, stop_xpm),
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM (preferences_cb, NULL),
 	GNOMEUIINFO_SEPARATOR,
@@ -40,7 +40,7 @@ static GnomeUIInfo docklet_menu [] = {
 
 static GnomeUIInfo firewall_menu [] = {
 	GNOMEUIINFO_ITEM (N_("_Run firewall wizard"), NULL, rundruid, wizard_xpm),
-	GNOMEUIINFO_ITEM (N_("R_estart firewall"), NULL, restart_firewall, start_xpm),
+	GNOMEUIINFO_ITEM (N_("Start _firewall"), NULL, restart_firewall, start_xpm),
 	GNOMEUIINFO_ITEM (N_("_Stop firewall"), NULL, stop_firewall, stop_xpm),
 	GNOMEUIINFO_ITEM (N_("_Halt all network traffic"), NULL, halt_traffic, stop_xpm),
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM (preferences_cb, NULL),
@@ -89,7 +89,7 @@ static GnomeUIInfo hitlog_menu [] = {
 	GNOMEUIINFO_ITEM (N_("Open service to machine"), NULL, open_service_to_machine, NULL),
 	GNOMEUIINFO_ITEM (N_("Open service to anyone"), NULL, open_service_to_anyone, NULL),
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_ITEM (N_("Do not log this port"), NULL, do_not_log_port_clist, NULL),
+	GNOMEUIINFO_ITEM (N_("Block and stop logging this port"), NULL, do_not_log_port_clist, NULL),
 	GNOMEUIINFO_ITEM (N_("Lookup hostname"), NULL, lookup, NULL),
 	GNOMEUIINFO_END
 };
