@@ -129,12 +129,18 @@ parse_hit_log (char *line)
 		width = gtk_clist_optimal_column_width (GTK_CLIST (hitlogclist), i);
 		gtk_clist_set_column_width (GTK_CLIST (hitlogclist), i, width);
 	}
+
+	/* Scroll the clist to the end */
+	while (gtk_clist_get_text (GTK_CLIST (hitlogclist), i, 0, NULL))
+		i++;
+	gtk_clist_moveto (GTK_CLIST (hitlogclist), i-1, 0, 0.0, 0.0);
+	
 	gtk_widget_queue_draw (hitlogclist);
 
 	gtk_object_set_data (GTK_OBJECT (hitlogclist),
-			     g_strdup_printf ("%d", datakey), proto);
+		g_strdup_printf ("%d", datakey), proto);
 	gtk_object_set_data (GTK_OBJECT (hitlogclist),
-			     "keys", GINT_TO_POINTER (datakey));
+		"keys", GINT_TO_POINTER (datakey));
 	++datakey;
 
 	return TRUE;
@@ -259,7 +265,7 @@ parse_do_not_log_ports (GtkWidget *clist)
 	FILE *f;
 
 
-	f = fopen (FIRESTARTER_RULES_DIR "/firestarter/do-not-log-ports", "r");
+	f = fopen (FIRESTARTER_RULES_DIR "/firestarter/block-ports", "r");
 
 	if (f == NULL) {
 		return;
