@@ -17,7 +17,7 @@
 #include "modrules.h"
 #include "parse.h"
 
-#include "xpm/play.xpm"
+/* #include "xpm/play.xpm" */
 
 #define LOG 0
 #define HIT 1
@@ -55,15 +55,17 @@ GtkWidget *filesel;
 
 gboolean ifo = FALSE;
 
-static GtkWidget *create_browse_button (GtkWidget *button, gint which);
 /*
+static GtkWidget *create_browse_button (GtkWidget *button, gint which);
+
 static void 	 create_filesel	       (GtkWidget *widget, gpointer data);
 static void	 set_file_log	       (GtkWidget *widget, gpointer data);
 static void	 set_file_hit	       (GtkWidget *widget, gpointer data);
 static void 	 set_file_stop	       (GtkWidget *widget, gpointer data);
 static void 	 set_file_restart      (GtkWidget *widget, gpointer data);
-*/
+
 static void 	 give_false_ifo	       (GtkWidget *widget, gpointer data);
+*/
 static void 	 destroy_filesel       (GtkWidget *pbox,   gpointer data);
 
 /* [ starthidden_sensitive ]
@@ -116,9 +118,10 @@ save_preferences (GnomePropertyBox *property_box, gint page_num, gint num)
 			gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (starthidden)));
 	else
 		gnome_config_set_bool ("/firestarter/Program/starthidden", FALSE);
-
+/*
 	gnome_config_set_bool ("/firestarter/Program/removedups",
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (removedups)));
+*/
 /* Logging */
 
 	fclose (f);
@@ -416,7 +419,7 @@ create_log_page (GtkWidget *pbox)
 	GtkWidget *entry;
 	GtkWidget *frame;
 	GtkWidget *vbox, *hbox;
-	GtkWidget *label;
+/*	GtkWidget *label; */
 	gchar *logtitles[2];
 
 	logtitles[0] = _("Port");
@@ -440,6 +443,7 @@ create_log_page (GtkWidget *pbox)
 	gtk_widget_set_usize (logclist, 175, 130);
 	gtk_clist_set_column_width (GTK_CLIST (logclist), 0, 50);
 	parse_do_not_log_ports (logclist);
+
 	gtk_signal_connect (GTK_OBJECT (logclist), "select-row",
 		GTK_SIGNAL_FUNC (log_clist_select), NULL);
 
@@ -509,11 +513,12 @@ create_log_page (GtkWidget *pbox)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (removedups),
 		gnome_config_get_bool ("/firestarter/Program/removedups=TRUE"));
 	gtk_box_pack_start (GTK_BOX (vbox), removedups, FALSE, FALSE, 5);
-	*/
 
 	gtk_signal_connect_object (GTK_OBJECT (removedups), "toggled",
 		GTK_SIGNAL_FUNC (gnome_property_box_changed), GTK_OBJECT (pbox));
 
+	*/
+
 	return table;
 }
 
