@@ -58,15 +58,18 @@ check_version (void)
 		GtkWidget *label;
 		int button;
 
-		mkdir (FIRESTARTER_RULES_DIR "/firestarter", 00700);
+		if (!mkdir (FIRESTARTER_RULES_DIR "/firestarter", 00700))
+			perror("Failed to firestarter configuration directory");
 
 		dialog = gnome_dialog_new (_("Old version detected"),
 			GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO, NULL);
 
 		label = gtk_label_new (_(
-			"\nA firewall created by an older version of\n"
+			"\nA firewall created by an older version of "
 			"Firestarter has been detected.\n\n"
-			"OK to remove old firewall (recommended)?\n"));
+			"OK to remove old firewall?\n"
+			"Old firewall settings will be stored in "
+			FIRESTARTER_RULES_DIR "/firestarter/backup"));
 		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox),
 			label, FALSE, FALSE, 0);
 		gtk_widget_show (label);
@@ -75,20 +78,32 @@ check_version (void)
 
 		switch (button) {
 			case 0:
-				remove (FIRESTARTER_RULES_DIR "/firestarter/firewall.sh");
-				remove (FIRESTARTER_RULES_DIR "/firestarter/allow-all");
-				remove (FIRESTARTER_RULES_DIR "/firestarter/deny-all");
-				remove (FIRESTARTER_RULES_DIR "/firestarter/allow-service-all");
-				remove (FIRESTARTER_RULES_DIR "/firestarter/allow-service-machine");
-				remove (FIRESTARTER_RULES_DIR "/firestarter/block-ports");
+				if (!mkdir (FIRESTARTER_RULES_DIR "/firestarter/backup", 00700))
+					perror("Failed to create backup directory");
+
+				rename (FIRESTARTER_RULES_DIR "/firestarter/firewall.sh",
+					FIRESTARTER_RULES_DIR "/firestarter/backup/firewall.sh");
+				rename (FIRESTARTER_RULES_DIR "/firestarter/allow-all",
+					FIRESTARTER_RULES_DIR "/firestarter/backup/allow-all");
+				rename (FIRESTARTER_RULES_DIR "/firestarter/deny-all",
+					FIRESTARTER_RULES_DIR "/firestarter/backup/deny-all");
+				rename (FIRESTARTER_RULES_DIR "/firestarter/allow-service-all",
+					FIRESTARTER_RULES_DIR "/firestarter/backup/allow-service-all");
+				rename (FIRESTARTER_RULES_DIR "/firestarter/allow-service-machine",
+					FIRESTARTER_RULES_DIR "/firestarter/backup/allow-service-machine");
+				rename (FIRESTARTER_RULES_DIR "/firestarter/block-ports",
+					FIRESTARTER_RULES_DIR "/firestarter/backup/block-ports");
+				rename (FIRESTARTER_RULES_DIR "/firestarter/portfw",
+					FIRESTARTER_RULES_DIR "/firestarter/backup/portfw");
+
 				gnome_config_set_bool ("/firestarter/Druid/firsttime", TRUE);
 				gnome_config_sync ();
-				printf ("Scripts removed");
+				printf ("Scripts moved to " FIRESTARTER_RULES_DIR "/firestarter/backup\n");
 				break;
 
 			case 1:
 			case -1:
-				printf ("Scripts not removed");
+				printf ("Scripts not removed\n");
 				break;
 		}
 	}
